@@ -146,7 +146,7 @@ usage (int status)
   fprintf (f, "-h --help                    give this help\n");
   fprintf (f, "-i --ignore-arch-all         ignore Architecture: all source packages\n");
   fprintf (f, "-p --packages                filename of Packages file.\n");
-  fprintf (f, "                              default: Packages in cwd\nn");
+  fprintf (f, "                              default: Packages in cwd\n");
   fprintf (f, "-s --source-packages         filename of Sources file.\n");
   fprintf (f, "                              default: Sources in cwd\n");
   fprintf (f, "-w --warn-older              warn about packages older in Sources file\n");
